package Handler::Javascript::Interpreter;

use strict;

use CGI;
use JavaScript;

use Class::MethodMaker
    [
        scalar => [ qw/ interpreter context / ],
        new    => [ qw/ -init new / ],
    ];

sub init
{
    my ($self) = @_;
    
    $self->{output} = '';
    $self->interpreter(JavaScript::Runtime->new());
    $self->context($self->interpreter->create_context());

    $self->context->bind_function(write => sub {
        $self->{output} .= join("", @_);
    });
    

    $self->context->bind_class(
        name => 'Request',
        constructor => sub { return CGI->new(); },
        package => 'CGI',
        methods => { param => \&CGI::param, header => \&CGI::header }
    );
    
}

sub interpret
{
    my ($self, $js) = @_;
    
    $self->{output} = '';

    $self->context->eval($js);
}

sub output
{
    my ($self) = @_;
    
    return $self->{output};
}

1;